@@ -2,14 +2,14 @@ package SPVM::Stringable;
 
 1;
 
-=head1 NAME
+=head1 Name
 
 SPVM::Stringable - A Interface Type to Stringify a Object
 
-=head1 SYNOPSYS
+=head1 Usage
   
   class Point {
-    implement Stringable;
+    interface Stringable;
   
     method to_string : string ();
       my $x = $sel->x;
@@ -21,16 +21,16 @@ SPVM::Stringable - A Interface Type to Stringify a Object
     };
   }
 
-=head1 DESCRIPTION
+=head1 Description
 
 L<Stringable|SPVM::Stringable> is a interface type to stringify a object.
 
-=head1 INTERFACE METHODS
+=head1 Interface Methods
 
 Interface methods.
 
 =head2 to_string
 
-  method to_string : string ();
+  required method to_string : string ();
 
 The implementation must return the string expression.
